Skip to contents

Scrape the USADA website sanctions data

Usage

scrape_sanctions(dest_path)

Arguments

dest_path

path to directory where the scraped data will be saved

Value

called for its side effect of exporting the scraped sanctions table to dest_path via export_data().

Examples

# scrape_sanctions()