Scrape the USADA website sanctions data
scrape_sanctions.RdScrape the USADA website sanctions data
Value
called for its side effect of exporting the scraped sanctions table
to dest_path via export_data().
scrape_sanctions.RdScrape the USADA website sanctions data
called for its side effect of exporting the scraped sanctions table
to dest_path via export_data().