Skip to contents

Scrapes the current USADA sanctions page and overwrites the local cache used by get_sanctions_data() and get_prohibited_association(). This is the only function in the package that makes a network request.

Usage

update_sanctions_data(verbose = FALSE)

Arguments

verbose

print progress messages. Default FALSE

Value

called for its side effect of writing the local cache. Returns invisible(NULL)

Examples

# \donttest{
update_sanctions_data(verbose = TRUE)
#> Scraping: https://www.usada.org/results/sanctions/
#> Sanctions data cache refreshed.
# }